pub fn ax_flush_file(file: &AxFileHandle) -> AxResultExpand description
Flushes the file, writes all buffered data to the underlying device.
pub fn ax_flush_file(file: &AxFileHandle) -> AxResultFlushes the file, writes all buffered data to the underlying device.