pub fn ax_open_dir(path: &str, opts: &AxOpenOptions) -> AxResult<AxDirHandle>Expand description
Opens a directory at the path relative to the current directory with
the options specified by opts.
pub fn ax_open_dir(path: &str, opts: &AxOpenOptions) -> AxResult<AxDirHandle>Opens a directory at the path relative to the current directory with
the options specified by opts.