pub fn ax_open_file(path: &str, opts: &AxOpenOptions) -> AxResult<AxFileHandle>Expand description
Opens a file at the path relative to the current directory with the
options specified by opts.
pub fn ax_open_file(path: &str, opts: &AxOpenOptions) -> AxResult<AxFileHandle>Opens a file at the path relative to the current directory with the
options specified by opts.