Function ax_read_file

pub fn ax_read_file(file: &mut AxFileHandle, buf: &mut [u8]) -> AxResult<usize>
Reads the file at the current position, returns the number of bytes read.

After the read, the cursor will be advanced by the number of bytes read.