pub fn ax_seek_file(file: &mut AxFileHandle, pos: AxSeekFrom) -> AxResult<u64>Expand description
Sets the cursor of the file to the specified offset. Returns the new position after the seek.
pub fn ax_seek_file(file: &mut AxFileHandle, pos: AxSeekFrom) -> AxResult<u64>Sets the cursor of the file to the specified offset. Returns the new position after the seek.