Function ax_write_file

pub fn ax_write_file(file: &mut AxFileHandle, buf: &[u8]) -> AxResult<usize>
Writes the file at the current position, returns the number of bytes written.

After the write, the cursor will be advanced by the number of bytes written.